@@ -1,9 +1,12 @@
-from typing import List, Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, List, Optional
 
 from typing_extensions import Literal, NotRequired, TypedDict
 
-from ..shared import Snowflake
-from .user import UserData
+if TYPE_CHECKING:
+    from ..shared import Snowflake
+    from .user import UserData
 
 __all__ = ('StickerItemData', 'StickerData', 'StickerPackData')
 
