@@ -1,9 +1,12 @@
-from typing import Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Optional
 
 from typing_extensions import NotRequired, TypedDict
 
-from ..shared import Snowflake
-from .guild import GuildMemberData
+if TYPE_CHECKING:
+    from ..shared import Snowflake
+    from .guild import GuildMemberData
 
 __all__ = ('VoiceStateData', 'VoiceRegionData')
 
