@@ -1,11 +1,14 @@
-from typing import Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Optional
 
 from typing_extensions import Literal, NotRequired, TypedDict
 
-from ..shared import Snowflake
-from .channel import PartialChannelData
-from .guild import GuildData
-from .user import UserData
+if TYPE_CHECKING:
+    from ..shared import Snowflake
+    from .channel import PartialChannelData
+    from .guild import GuildData
+    from .user import UserData
 
 __all__ = ('WebhookData',)
 
